@@ -200,9 +200,11 @@ class Page(BaseModel):
             'fan_count': None,
             'founded': None,  # only for category_list has company
             'global_brand_root_id': None,
+            'global_brand_page_name': None,
             'link': None,
             'name': None,
             'phone': None,
+            'picture': None,
             'rating_count': None,
             'single_line_address': None,
             'username': None,
@@ -230,9 +232,12 @@ class Page(BaseModel):
         engagement = data.get('engagement')
         if engagement:
             engagement = PageEngagement.new_from_json_dict(engagement)
+        picture = data.get('picture', {}).get('data')
+        if picture:
+            picture = PagePicture.new_from_json_dict(picture)
         return super(cls, cls).new_from_json_dict(
             data=data, category_list=category_list,
-            cover=cover, engagement=engagement
+            cover=cover, engagement=engagement, picture=picture
         )
 
 
